@@@@@@@
Credits
@@@@@@@

.. |dob| replace:: ``dob``
.. _dob: https://github.com/hotoffthehamster/dob

.. |dob-bright| replace:: ``dob-bright``
.. _dob-bright: https://github.com/hotoffthehamster/dob-bright

.. |dob-prompt| replace:: ``dob-prompt``
.. _dob-prompt: https://github.com/hotoffthehamster/dob-prompt

.. |dob-viewer| replace:: ``dob-viewer``
.. _dob-viewer: https://github.com/hotoffthehamster/dob-viewer

.. |nark| replace:: ``nark``
.. _nark: https://github.com/hotoffthehamster/nark

.. |hamster-cli| replace:: ``hamster-cli``
.. _hamster-cli: https://github.com/projecthamster/hamster-cli

.. |Landon Bouma| replace:: Landon Bouma
.. _Landon Bouma: https://www.tallybark.com/

.. |HotOffThe Hamster| replace:: HotOffThe Hamster
.. _HotOffThe Hamster: https://github.com/hotoffthehamster

########################
``dob`` (2018 — Present)
########################

Project Lead
============

* |Landon Bouma|_ for
  |HotOffThe Hamster|_.

Coupled Projects
================

* |dob|_'s ``edit`` command is a thin wrapper around features
  provided by two other projects, |dob-prompt|_ and |dob-viewer|_,
  and all three projects use another common component, |dob-bright|_.

* And of course |dob|_'s hamster heart is furnished by |nark|_.

Please see those projects' docs for additional shout-outs and acknowledgements.

Others Credits
==============

HotOffThe Hamster Emblem
------------------------

.. |hothicon| replace:: *HotOffThe Hamster*
.. _hothicon: https://avatars1.githubusercontent.com/u/40221513?s=400&v=4

.. |lbghub| replace:: Landon Bouma
.. _lbghub: https://github.com/landonb

|hothicon|_ illustration
by |lbghub|_,
derived from:
`Desert <https://www.flaticon.com/free-icon/desert_190898>`__,
by `Freepik <https://www.freepik.com/>`__,
from `www.flaticon.com <https://www.flaticon.com/>`__,
licensed by `CC 3.0 BY <https://creativecommons.org/licenses/by/3.0/>`__;
`Hamster Wheel <https://thenounproject.com/term/hamster-wheel/4739/>`__,
by `Olivier Guin <https://thenounproject.com/olivierguin>`__,
from `the Noun Project <https://thenounproject.com>`__; and
`Sun <https://thenounproject.com/term/sun/1888465/>`__,
by `Valerie Lamm <https://thenounproject.com/my__valerie>`__,
from `the Noun Project <https://thenounproject.com>`__.

#############################
``hamster-cli`` (2015 — 2017)
#############################

.. |legaham| replace:: *legacy Hamster*
.. _legaham: https://github.com/projecthamster/hamster

HOTH owes a ton of gratitude to
`Eric Goller <https://github.com/elbenfreund>`_
for reviving |legaham|_ with |hamster-cli|_,
a thoughtful, modern rewrite (using microservices) with great test coverage.
Anyone should find their code easy to read, quick to grok, and fun to hack.

- *dob was originally forked from hamster-cli, then modified heavily.
  You'll find some of the original code still exists around dob.*

Creator/Lead
============

* `Eric Goller <https://github.com/elbenfreund>`_

Contributors
============

* `Stefan Mertl <https://github.com/scientificsteve>`_

